package
Version:
v1.0.16
Opens a new window with list of versions in this module.
Published: Feb 1, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
const (
EPS1 = 1e-1
EPS2 = 1e-2
EPS3 = 1e-3
EPS4 = 1e-4
EPS5 = 1e-5
EPS6 = 1e-6
EPS9 = 1e-9
EPS = 1e-12
)
func Clip[T cmp.Ordered](value, minVal, maxVal T) T
Source Files
¶
Click to show internal directories.
Click to hide internal directories.